Record Class AppVersionKey

java.lang.Object
java.lang.Record
com.google.apphosting.base.AppVersionKey

@Immutable public record AppVersionKey(String appId, String versionId) extends Record
A simple immutable data container class that identifies a single version of specific application.

Static factory methods are provided to create AppVersionKey's from AppInfo and UPRequests.

  • Constructor Details

    • AppVersionKey

      public AppVersionKey(String appId, String versionId)
      Creates an instance of a AppVersionKey record class.
      Parameters:
      appId - the value for the appId record component
      versionId - the value for the versionId record component
  • Method Details

    • fromAppInfo

      public static AppVersionKey fromAppInfo(com.google.apphosting.base.protos.AppinfoPb.AppInfo appInfo)
    • fromUpRequest

      public static AppVersionKey fromUpRequest(com.google.apphosting.base.protos.RuntimePb.UPRequest request)
    • of

      public static AppVersionKey of(String appId, String versionId)
    • getAppId

      public String getAppId()
    • getVersionId

      public String getVersionId()
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • appId

      public String appId()
      Returns the value of the appId record component.
      Returns:
      the value of the appId record component
    • versionId

      public String versionId()
      Returns the value of the versionId record component.
      Returns:
      the value of the versionId record component