Package com.google.apphosting.base
Record Class VersionId
java.lang.Object
java.lang.Record
com.google.apphosting.base.VersionId
public record VersionId(@Nullable String versionId, String majorVersion, String engineId, String engineVersionId, @Nullable String minorVersion)
extends Record
A parsed Version Id.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionengineId()Returns the value of theengineIdrecord component.Returns the value of theengineVersionIdrecord component.final booleanIndicates whether some other object is "equal to" this one.Returns the serverId.Returns the server version id.Returns the majorVersion.@Nullable StringReturns the minorVersion ornullif no minor version was present.@Nullable StringReturns the versionId.final inthashCode()Returns a hash code value for this object.Returns the value of themajorVersionrecord component.@Nullable StringReturns the value of theminorVersionrecord component.static VersionIdfinal StringtoString()Returns a string representation of this record class.@Nullable StringReturns the value of theversionIdrecord component.
-
Field Details
-
DEFAULT_ENGINE_ID
- See Also:
-
-
Constructor Details
-
VersionId
public VersionId(@Nullable String versionId, String majorVersion, String engineId, String engineVersionId, @Nullable String minorVersion) Creates an instance of aVersionIdrecord class.- Parameters:
versionId- the value for theversionIdrecord componentmajorVersion- the value for themajorVersionrecord componentengineId- the value for theengineIdrecord componentengineVersionId- the value for theengineVersionIdrecord componentminorVersion- the value for theminorVersionrecord component
-
-
Method Details
-
parse
-
getVersionId
Returns the versionId. -
getMajorVersion
Returns the majorVersion. -
getEngineId
Returns the serverId. -
getEngineVersionId
Returns the server version id. -
getMinorVersion
Returns the minorVersion ornullif no minor version was present. -
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
versionId
Returns the value of theversionIdrecord component.- Returns:
- the value of the
versionIdrecord component
-
majorVersion
Returns the value of themajorVersionrecord component.- Returns:
- the value of the
majorVersionrecord component
-
engineId
Returns the value of theengineIdrecord component.- Returns:
- the value of the
engineIdrecord component
-
engineVersionId
Returns the value of theengineVersionIdrecord component.- Returns:
- the value of the
engineVersionIdrecord component
-
minorVersion
Returns the value of theminorVersionrecord component.- Returns:
- the value of the
minorVersionrecord component
-