Package com.google.apphosting.runtime
Class ApiDeadlineOracle
java.lang.Object
com.google.apphosting.runtime.ApiDeadlineOracle
ApiDeadlineOracle determines the appropriate deadline for API calls based on the
user-specified deadline, the per-package maximum and default deadlines, and the fallthrough
maximum and default deadlines.
This class is also used to track shared buffer counts and sizes as they can also be specified on a per-package and online/offline basis.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuild an ApiDeadlineOracle.static classDeadlines for one instance type (offline or online). -
Method Summary
Modifier and TypeMethodDescriptionvoidaddPackageDefaultDeadline(String packageName, double defaultDeadline) voidaddPackageMaxDeadline(String packageName, double maxDeadline) voidaddPackageMaxRequestSize(String packageName, long maxRequestSize) voidaddPackageMinContentSizeForBuffer(String packageName, long minContentSizeForBuffer) doublegetDeadline(String packageName, boolean isOffline, Number userDeadline)
-
Method Details
-
getDeadline
-
addPackageDefaultDeadline
-
addPackageMaxDeadline
-
addPackageMinContentSizeForBuffer
-
addPackageMaxRequestSize
-