Package com.google.apphosting.runtime
Class AppEngineConstants
java.lang.Object
com.google.apphosting.runtime.AppEngineConstants
AppEngineConstants centralizes some constants that are specific to our use of Jetty.-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringThisServletContextattribute contains theAppVersionfor the current application.static final StringThisServletRequestattribute contains theAppVersionKeyidentifying the current application. identify which application version to use.static final Stringstatic final Stringstatic final Stringstatic final longFlush application logs when they grow to this size.static final longHow many CPU cycles should be assumed per second for billing purposes.static final intThe maximum number of simultaneous APIHost RPCs.static final Stringstatic final Stringstatic final booleanForce url-stream-handler to 'urlfetch' irrespective of the contents of the appengine-web.xml descriptor.static final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final intThe Jetty request header size in bytes (256K).static final intThe Jetty response header size in bytes (256K).static final DurationMaximum time a log record should be allowed to to be cached in the runtime before being flushed to the appserver (only applies to non-frontend requests).static final intMaximum application log line size.static final intThe maximum request size in bytes (32M).static final intThe maximum response size in bytes (32M).static final longThe maximum allowed size in bytes of the Runtime Log per request, returned in the UPResponse.static final com.google.common.collect.ImmutableSet<String> static final Stringstatic final intIf positive, send thread interrupts this many milliseconds before the hard deadline.static final booleanAlways terminate the clone when Thread.stop() is used.static final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final StringThe HTTP headers that are handled specially by this proxy are defined in lowercase because HTTP headers are case-insensitive, and we look then up in a set or switch after converting to lower-case.static final Stringstatic final Stringstatic final String -
Method Summary
Modifier and TypeMethodDescriptionstatic booleanSet the Jetty request with Async mode.static booleanIf Legacy Mode is turned on, then Jetty is configured to be more forgiving of bad requests and to act more in the style of Jetty-9.3
-
Field Details
-
MAX_RUNTIME_LOG_PER_REQUEST
public static final long MAX_RUNTIME_LOG_PER_REQUESTThe maximum allowed size in bytes of the Runtime Log per request, returned in the UPResponse.- See Also:
-
DEFAULT_MAX_OUTSTANDING_API_RPCS
public static final int DEFAULT_MAX_OUTSTANDING_API_RPCSThe maximum number of simultaneous APIHost RPCs.- See Also:
-
BYTE_COUNT_BEFORE_FLUSHING
public static final long BYTE_COUNT_BEFORE_FLUSHINGFlush application logs when they grow to this size.- See Also:
-
MAX_LOG_LINE_SIZE
public static final int MAX_LOG_LINE_SIZEMaximum application log line size.- See Also:
-
MAX_LOG_FLUSH_TIME
Maximum time a log record should be allowed to to be cached in the runtime before being flushed to the appserver (only applies to non-frontend requests). -
THREAD_STOP_TERMINATES_CLONE
public static final boolean THREAD_STOP_TERMINATES_CLONEAlways terminate the clone when Thread.stop() is used.- See Also:
-
FORCE_URLFETCH_URL_STREAM_HANDLER
public static final boolean FORCE_URLFETCH_URL_STREAM_HANDLERForce url-stream-handler to 'urlfetch' irrespective of the contents of the appengine-web.xml descriptor.- See Also:
-
GAE_RUNTIME
-
APP_VERSION_CONTEXT_ATTR
ThisServletContextattribute contains theAppVersionfor the current application.- See Also:
-
APP_VERSION_KEY_REQUEST_ATTR
ThisServletRequestattribute contains theAppVersionKeyidentifying the current application. identify which application version to use.- See Also:
-
APP_YAML_ATTRIBUTE_TARGET
- See Also:
-
X_FORWARDED_PROTO
The HTTP headers that are handled specially by this proxy are defined in lowercase because HTTP headers are case-insensitive, and we look then up in a set or switch after converting to lower-case.- See Also:
-
X_APPENGINE_API_TICKET
- See Also:
-
X_APPENGINE_HTTPS
- See Also:
-
X_APPENGINE_USER_IP
- See Also:
-
X_APPENGINE_USER_EMAIL
- See Also:
-
X_APPENGINE_AUTH_DOMAIN
- See Also:
-
X_APPENGINE_USER_ID
- See Also:
-
X_APPENGINE_USER_NICKNAME
- See Also:
-
X_APPENGINE_USER_ORGANIZATION
- See Also:
-
X_APPENGINE_USER_IS_ADMIN
- See Also:
-
X_APPENGINE_TRUSTED_IP_REQUEST
- See Also:
-
X_APPENGINE_LOAS_PEER_USERNAME
- See Also:
-
X_APPENGINE_ID_HASH
- See Also:
-
X_APPENGINE_GAIA_ID
- See Also:
-
X_APPENGINE_GAIA_AUTHUSER
- See Also:
-
X_APPENGINE_GAIA_SESSION
- See Also:
-
X_APPENGINE_APPSERVER_DATACENTER
- See Also:
-
X_APPENGINE_APPSERVER_TASK_BNS
- See Also:
-
X_APPENGINE_DEFAULT_VERSION_HOSTNAME
- See Also:
-
X_APPENGINE_REQUEST_LOG_ID
- See Also:
-
X_APPENGINE_QUEUENAME
- See Also:
-
X_APPENGINE_TIMEOUT_MS
- See Also:
-
X_GOOGLE_INTERNAL_SKIPADMINCHECK
- See Also:
-
X_GOOGLE_INTERNAL_SKIPADMINCHECK_UC
- See Also:
-
X_GOOGLE_INTERNAL_PROFILER
- See Also:
-
X_CLOUD_TRACE_CONTEXT
- See Also:
-
X_APPENGINE_BACKGROUNDREQUEST
- See Also:
-
BACKGROUND_REQUEST_URL
- See Also:
-
WARMUP_REQUEST_URL
- See Also:
-
BACKGROUND_REQUEST_SOURCE_IP
- See Also:
-
PRIVATE_APPENGINE_HEADERS
-
IS_ADMIN_HEADER_VALUE
- See Also:
-
IS_TRUSTED
- See Also:
-
SKIP_ADMIN_CHECK_ATTR
- See Also:
-
WARMUP_IP
- See Also:
-
UNSPECIFIED_IP
- See Also:
-
DEFAULT_SECRET_KEY
- See Also:
-
ENVIRONMENT_ATTR
- See Also:
-
HTTP_CONNECTOR_MODE
- See Also:
-
IGNORE_RESPONSE_SIZE_LIMIT
- See Also:
-
SOFT_DEADLINE_DELAY_MS
public static final int SOFT_DEADLINE_DELAY_MSIf positive, send thread interrupts this many milliseconds before the hard deadline.- See Also:
-
CYCLES_PER_SECOND
public static final long CYCLES_PER_SECONDHow many CPU cycles should be assumed per second for billing purposes.- See Also:
-
JETTY_REQUEST_HEADER_SIZE
public static final int JETTY_REQUEST_HEADER_SIZEThe Jetty request header size in bytes (256K).- See Also:
-
JETTY_RESPONSE_HEADER_SIZE
public static final int JETTY_RESPONSE_HEADER_SIZEThe Jetty response header size in bytes (256K).- See Also:
-
MAX_REQUEST_SIZE
public static final int MAX_REQUEST_SIZEThe maximum request size in bytes (32M).- See Also:
-
MAX_RESPONSE_SIZE
public static final int MAX_RESPONSE_SIZEThe maximum response size in bytes (32M).- See Also:
-
-
Method Details
-
isLegacyMode
public static boolean isLegacyMode()If Legacy Mode is turned on, then Jetty is configured to be more forgiving of bad requests and to act more in the style of Jetty-9.3 -
isAsyncMode
public static boolean isAsyncMode()Set the Jetty request with Async mode.
-