Package com.google.apphosting.runtime
Class AppVersion
java.lang.Object
com.google.apphosting.runtime.AppVersion
AppVersion encapsulates the configuration information
associated with one version of a particular application. Do not
construct a AppVersion directly, instead use AppVersionFactory.- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AppVersion.Builderbuilder()Return a builder for an AppVersion instance.Returns the customClassLoaderthat will safely load classes and resource files that were published along with this application version.com.google.apphosting.runtime.ApplicationEnvironmentReturns the environment which was configured for the application.getKey()Returns theAppVersionKeythat can be used as an identifier for thisAppVersion.Returns the parent directory for all static and resource files.Returns the top-level directory under which all application version resource files are made available.com.google.apphosting.runtime.SessionsConfigbooleanisResourceFile(String path) Returns true ifpathis a resource file that was uploaded as part of this application.booleanisStaticFile(String path) Returns true ifpathis a static file that was uploaded to BlobStore for use by this application.
-
Method Details
-
builder
Return a builder for an AppVersion instance. -
getKey
Returns theAppVersionKeythat can be used as an identifier for thisAppVersion. -
getRootDirectory
Returns the top-level directory under which all application version resource files are made available. -
getClassLoader
Returns the customClassLoaderthat will safely load classes and resource files that were published along with this application version. -
getEnvironment
public com.google.apphosting.runtime.ApplicationEnvironment getEnvironment()Returns the environment which was configured for the application. -
getSessionsConfig
public com.google.apphosting.runtime.SessionsConfig getSessionsConfig() -
isResourceFile
Returns true ifpathis a resource file that was uploaded as part of this application. -
isStaticFile
Returns true ifpathis a static file that was uploaded to BlobStore for use by this application. -
getPublicRoot
Returns the parent directory for all static and resource files. -
getThreadGroupPool
-