Package com.google.apphosting.runtime
Class AppVersionFactory.Builder
java.lang.Object
com.google.apphosting.runtime.AppVersionFactory.Builder
- Enclosing class:
AppVersionFactory
Builder for AppVersionFactory.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionabstract AppVersionFactorybuild()abstract AppVersionFactory.Builderabstract AppVersionFactory.BuildersetForceUrlfetchUrlStreamHandler(boolean x) abstract AppVersionFactory.BuilderThe runtime version which is reported to users.abstract AppVersionFactory.BuildersetSandboxPlugin(com.google.apphosting.runtime.NullSandboxPlugin x) The root directory where all application versions are persisted.abstract AppVersionFactory.Builder
-
Constructor Details
-
Builder
public Builder()
-
-
Method Details
-
setSandboxPlugin
public abstract AppVersionFactory.Builder setSandboxPlugin(com.google.apphosting.runtime.NullSandboxPlugin x) The root directory where all application versions are persisted. -
setRuntimeVersion
The runtime version which is reported to users. -
setForceUrlfetchUrlStreamHandler
-
setFixedApplicationPath
-
build
-