Interface RequestAPIData

All Known Implementing Classes:
UpRequestAPIData

public interface RequestAPIData
This interface defines a set of operations required for a Request to be used by the Java Runtime.
  • Method Details

    • getObfuscatedGaiaId

      String getObfuscatedGaiaId()
    • getUserOrganization

      String getUserOrganization()
    • getIsTrustedApp

      boolean getIsTrustedApp()
    • getTrusted

      boolean getTrusted()
    • getPeerUsername

      String getPeerUsername()
    • getSecurityLevel

      String getSecurityLevel()
    • getHeadersList

      Stream<com.google.apphosting.base.protos.HttpPb.ParsedHttpHeader> getHeadersList()
    • getIsOffline

      boolean getIsOffline()
    • getGaiaId

      long getGaiaId()
    • getAuthuser

      String getAuthuser()
    • getGaiaSession

      String getGaiaSession()
    • getAppserverDatacenter

      String getAppserverDatacenter()
    • getAppserverTaskBns

      String getAppserverTaskBns()
    • hasEventIdHash

      boolean hasEventIdHash()
    • getEventIdHash

      String getEventIdHash()
    • hasRequestLogId

      boolean hasRequestLogId()
    • getRequestLogId

      String getRequestLogId()
    • hasDefaultVersionHostname

      boolean hasDefaultVersionHostname()
    • getDefaultVersionHostname

      String getDefaultVersionHostname()
    • getAppId

      String getAppId()
    • getModuleId

      String getModuleId()
    • getModuleVersionId

      String getModuleVersionId()
    • getIsAdmin

      boolean getIsAdmin()
    • getEmail

      String getEmail()
    • getAuthDomain

      String getAuthDomain()
    • getSecurityTicket

      String getSecurityTicket()
    • hasTraceContext

      boolean hasTraceContext()
    • getTraceContext

      com.google.apphosting.base.protos.TracePb.TraceContextProto getTraceContext()
    • getUrl

      String getUrl()
    • getRequestType

      com.google.apphosting.base.protos.RuntimePb.UPRequest.RequestType getRequestType()
    • getBackgroundRequestId

      String getBackgroundRequestId()