Class RequestRunner

java.lang.Object
com.google.apphosting.runtime.RequestRunner
All Implemented Interfaces:
Runnable

public class RequestRunner extends Object implements Runnable
Runs an inbound request within the context of the given app, whether ordinary inbound HTTP or background request.
  • Field Details

    • WAIT_FOR_USER_RUNNABLE_DEADLINE

      public static final Duration WAIT_FOR_USER_RUNNABLE_DEADLINE
      How long should we wait for ApiProxyImpl to exchange the background thread's Runnable.
  • Constructor Details

  • Method Details

    • builder

      public static RequestRunner.Builder builder()
      Get a partly-initialized builder.
    • setFailure

      public static void setFailure(MutableUpResponse response, com.google.apphosting.base.protos.RuntimePb.UPResponse.ERROR error, String message)
      Create a failure response from the given code and message.
    • shouldKillCloneAfterException

      public static boolean shouldKillCloneAfterException(Throwable th)
    • run

      public void run()
      Specified by:
      run in interface Runnable