Class RequestRunner.EagerRunner

java.lang.Object
com.google.apphosting.runtime.RequestRunner.EagerRunner
All Implemented Interfaces:
Runnable
Enclosing class:
RequestRunner

public static class RequestRunner.EagerRunner extends Object implements Runnable
A runnable which lets us start running before we even know what to run. The run method first waits to be given a Runnable (from another thread) via the supplyRunnable method, and then we run that.