Uses of Class
com.google.apphosting.runtime.AppVersion
Packages that use AppVersion
-
Uses of AppVersion in com.google.apphosting.runtime
Methods in com.google.apphosting.runtime that return AppVersionModifier and TypeMethodDescriptionabstract AppVersionAppVersion.Builder.build()AppVersionFactory.createAppVersion(com.google.apphosting.base.protos.AppinfoPb.AppInfo appInfo, com.google.apphosting.utils.config.AppEngineWebXml appEngineWebXml, com.google.apphosting.runtime.ApplicationEnvironment.RuntimeConfiguration configuration) Create anAppVersionfrom the specifiedAppInfoprotocol buffer.AppVersionFactory.createAppVersionForTest(com.google.apphosting.base.protos.AppinfoPb.AppInfo appInfo) Creates a newAppVersionwith a default RuntimeConfiguration.ApiProxyImpl.EnvironmentImpl.getAppVersion()RequestManager.RequestToken.getAppVersion()Methods in com.google.apphosting.runtime with parameters of type AppVersionModifier and TypeMethodDescriptionvoidServletEngineAdapter.addAppVersion(AppVersion appVersion) Register the specified application version for future calls toserviceRequest.ApiProxyImpl.createEnvironment(AppVersion appVersion, com.google.apphosting.base.protos.RuntimePb.UPRequest request, MutableUpResponse response, @Nullable TraceWriter traceWriter, CpuRatioTimer requestTimer, String requestId, List<Future<?>> asyncFutures, Semaphore outstandingApiRpcSemaphore, ThreadGroup requestThreadGroup, RequestState requestState, @Nullable Long millisUntilSoftDeadline) ApiProxyImpl.createEnvironment(AppVersion appVersion, RequestAPIData request, ResponseAPIData response, @Nullable TraceWriter traceWriter, CpuRatioTimer requestTimer, String requestId, List<Future<?>> asyncFutures, Semaphore outstandingApiRpcSemaphore, ThreadGroup requestThreadGroup, RequestState requestState, @Nullable Long millisUntilSoftDeadline) Creates anApiProxy.Environmentinstance that is suitable for use with this class.abstract RequestRunner.BuilderRequestRunner.Builder.setAppVersion(AppVersion appVersion) RequestManager.startRequest(AppVersion appVersion, AnyRpcServerContext rpc, com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse, ThreadGroup requestThreadGroup) RequestManager.startRequest(AppVersion appVersion, AnyRpcServerContext rpc, RequestAPIData genericRequest, ResponseAPIData genericResponse, ThreadGroup requestThreadGroup) Set up any state necessary to execute a new request using the specified parameters.Constructors in com.google.apphosting.runtime with parameters of type AppVersionModifierConstructorDescriptionRequestRunner(UPRequestHandler upRequestHandler, RequestManager requestManager, BackgroundRequestCoordinator coordinator, AppVersion appVersion, AnyRpcServerContext rpc, com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse)