Uses of Class
com.google.apphosting.runtime.MutableUpResponse
Packages that use MutableUpResponse
-
Uses of MutableUpResponse in com.google.apphosting.runtime
Methods in com.google.apphosting.runtime with parameters of type MutableUpResponseModifier and TypeMethodDescriptionbooleanHttpCompression.attemptCompression(com.google.apphosting.base.protos.RuntimePb.UPRequest request, MutableUpResponse response) Attempt to compress the HttpResponse, using trusted and untrusted headers to determine if the client (or GFE) accepts compression for this response.ApiProxyImpl.createEnvironment(AppVersion appVersion, com.google.apphosting.base.protos.RuntimePb.UPRequest request, MutableUpResponse response, @Nullable TraceWriter traceWriter, CpuRatioTimer requestTimer, String requestId, List<Future<?>> asyncFutures, Semaphore outstandingApiRpcSemaphore, ThreadGroup requestThreadGroup, RequestState requestState, @Nullable Long millisUntilSoftDeadline) static @Nullable TraceWriterTraceWriter.getTraceWriterForRequest(com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse) voidUPRequestHandler.serviceRequest(com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse) Executes the HTTP request specified byupRequestand writes the response toupResponse.static voidRequestRunner.setFailure(MutableUpResponse response, com.google.apphosting.base.protos.RuntimePb.UPResponse.ERROR error, String message) Create a failure response from the given code and message.abstract RequestRunner.BuilderRequestRunner.Builder.setUpResponse(MutableUpResponse upResponse) RequestManager.startRequest(AppVersion appVersion, AnyRpcServerContext rpc, com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse, ThreadGroup requestThreadGroup) Constructors in com.google.apphosting.runtime with parameters of type MutableUpResponseModifierConstructorDescriptionAppLogsWriter(MutableUpResponse upResponse, long maxBytesToFlush, int maxLogMessageLength, int maxFlushSeconds) RequestRunner(UPRequestHandler upRequestHandler, RequestManager requestManager, BackgroundRequestCoordinator coordinator, AppVersion appVersion, AnyRpcServerContext rpc, com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse) TraceWriter(com.google.apphosting.api.CloudTraceContext context, MutableUpResponse upResponse) Deprecated.UpResponseAPIData(MutableUpResponse response)