Uses of Interface
com.google.apphosting.runtime.RequestAPIData
Packages that use RequestAPIData
-
Uses of RequestAPIData in com.google.apphosting.runtime
Classes in com.google.apphosting.runtime that implement RequestAPIDataMethods in com.google.apphosting.runtime with parameters of type RequestAPIDataModifier and TypeMethodDescriptionApiProxyImpl.createEnvironment(AppVersion appVersion, RequestAPIData request, ResponseAPIData response, @Nullable TraceWriter traceWriter, CpuRatioTimer requestTimer, String requestId, List<Future<?>> asyncFutures, Semaphore outstandingApiRpcSemaphore, ThreadGroup requestThreadGroup, RequestState requestState, @Nullable Long millisUntilSoftDeadline) Creates anApiProxy.Environmentinstance that is suitable for use with this class.static @Nullable TraceWriterTraceWriter.getTraceWriterForRequest(RequestAPIData request, ResponseAPIData response) RequestManager.startRequest(AppVersion appVersion, AnyRpcServerContext rpc, RequestAPIData genericRequest, ResponseAPIData genericResponse, ThreadGroup requestThreadGroup) Set up any state necessary to execute a new request using the specified parameters.