Uses of Interface
com.google.apphosting.runtime.ResponseAPIData
Packages that use ResponseAPIData
-
Uses of ResponseAPIData in com.google.apphosting.runtime
Classes in com.google.apphosting.runtime that implement ResponseAPIDataMethods in com.google.apphosting.runtime with parameters of type ResponseAPIDataModifier and TypeMethodDescriptionApiProxyImpl.createEnvironment(AppVersion appVersion, RequestAPIData request, ResponseAPIData response, @Nullable TraceWriter traceWriter, CpuRatioTimer requestTimer, String requestId, List<Future<?>> asyncFutures, Semaphore outstandingApiRpcSemaphore, ThreadGroup requestThreadGroup, RequestState requestState, @Nullable Long millisUntilSoftDeadline) Creates anApiProxy.Environmentinstance that is suitable for use with this class.voidRuntimeLogSink.flushLogs(ResponseAPIData response) static @Nullable TraceWriterTraceWriter.getTraceWriterForRequest(RequestAPIData request, ResponseAPIData response) RequestManager.startRequest(AppVersion appVersion, AnyRpcServerContext rpc, RequestAPIData genericRequest, ResponseAPIData genericResponse, ThreadGroup requestThreadGroup) Set up any state necessary to execute a new request using the specified parameters.Constructors in com.google.apphosting.runtime with parameters of type ResponseAPIDataModifierConstructorDescriptionAppLogsWriter(ResponseAPIData genericResponse, long maxBytesToFlush, int maxLogMessageLength, int maxFlushSeconds) Construct an AppLogsWriter instance.TraceWriter(com.google.apphosting.api.CloudTraceContext context, ResponseAPIData upResponse)