Package com.google.apphosting.base
Record Class AppVersionKey
java.lang.Object
java.lang.Record
com.google.apphosting.base.AppVersionKey
A simple immutable data container class that identifies a single
version of specific application.
Static factory methods are provided to create AppVersionKey's from AppInfo and UPRequests.
-
Constructor Summary
ConstructorsConstructorDescriptionAppVersionKey(String appId, String versionId) Creates an instance of aAppVersionKeyrecord class. -
Method Summary
Modifier and TypeMethodDescriptionappId()Returns the value of theappIdrecord component.final booleanIndicates whether some other object is "equal to" this one.static AppVersionKeyfromAppInfo(com.google.apphosting.base.protos.AppinfoPb.AppInfo appInfo) static AppVersionKeyfromUpRequest(com.google.apphosting.base.protos.RuntimePb.UPRequest request) getAppId()final inthashCode()Returns a hash code value for this object.static AppVersionKeyfinal StringtoString()Returns a string representation of this record class.Returns the value of theversionIdrecord component.
-
Constructor Details
-
AppVersionKey
Creates an instance of aAppVersionKeyrecord class.- Parameters:
appId- the value for theappIdrecord componentversionId- the value for theversionIdrecord component
-
-
Method Details
-
fromAppInfo
public static AppVersionKey fromAppInfo(com.google.apphosting.base.protos.AppinfoPb.AppInfo appInfo) -
fromUpRequest
public static AppVersionKey fromUpRequest(com.google.apphosting.base.protos.RuntimePb.UPRequest request) -
of
-
getAppId
-
getVersionId
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
appId
Returns the value of theappIdrecord component.- Returns:
- the value of the
appIdrecord component
-
versionId
Returns the value of theversionIdrecord component.- Returns:
- the value of the
versionIdrecord component
-