Package com.google.apphosting.runtime
Class RequestRunner
java.lang.Object
com.google.apphosting.runtime.RequestRunner
- All Implemented Interfaces:
Runnable
Runs an inbound request within the context of the given app, whether ordinary inbound HTTP or
background request.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuilder for RequestRunner.static classA runnable which lets us start running before we even know what to run. -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final DurationHow long should we wait forApiProxyImplto exchange the background thread'sRunnable. -
Constructor Summary
ConstructorsConstructorDescriptionRequestRunner(UPRequestHandler upRequestHandler, RequestManager requestManager, BackgroundRequestCoordinator coordinator, AppVersion appVersion, AnyRpcServerContext rpc, com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse) -
Method Summary
Modifier and TypeMethodDescriptionstatic RequestRunner.Builderbuilder()Get a partly-initialized builder.voidrun()static voidsetFailure(MutableUpResponse response, com.google.apphosting.base.protos.RuntimePb.UPResponse.ERROR error, String message) Create a failure response from the given code and message.static boolean
-
Field Details
-
WAIT_FOR_USER_RUNNABLE_DEADLINE
How long should we wait forApiProxyImplto exchange the background thread'sRunnable.
-
-
Constructor Details
-
RequestRunner
public RequestRunner(UPRequestHandler upRequestHandler, RequestManager requestManager, BackgroundRequestCoordinator coordinator, AppVersion appVersion, AnyRpcServerContext rpc, com.google.apphosting.base.protos.RuntimePb.UPRequest upRequest, MutableUpResponse upResponse)
-
-
Method Details
-
builder
Get a partly-initialized builder. -
setFailure
public static void setFailure(MutableUpResponse response, com.google.apphosting.base.protos.RuntimePb.UPResponse.ERROR error, String message) Create a failure response from the given code and message. -
shouldKillCloneAfterException
-
run
public void run()
-