Package com.google.apphosting.runtime
Interface ServletEngineAdapter
- All Superinterfaces:
UPRequestHandler
This interface abstracts away the details of starting up and
shutting down a servlet engine, as well as adapting between the
concrete classes that implement the Java Servlet API and the
Prometheus Untrusted Process API.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic classOptions to configure a Jetty HTTP server, forwarding servlet requests to the GAE Java runtime. -
Method Summary
Modifier and TypeMethodDescriptionvoidaddAppVersion(AppVersion appVersion) Register the specified application version for future calls toserviceRequest.voidsetSessionStoreFactory(com.google.apphosting.runtime.SessionStoreFactory factory) Deprecated.voidstart(String serverInfo, ServletEngineAdapter.Config runtimeOptions) Performs whatever setup is necessary for this servlet container.voidstop()Perform any shutdown procedures necessary for this servlet container.Methods inherited from interface com.google.apphosting.runtime.UPRequestHandler
serviceRequest
-
Method Details
-
start
Performs whatever setup is necessary for this servlet container. This method waits for setup to complete before returning.- Parameters:
serverInfo- The string that should be returned byServletContext.getServerInfo().runtimeOptions- Extra options, currently used for the Jetty HTTP adapter only.
-
stop
void stop()Perform any shutdown procedures necessary for this servlet container. This method should return once the shutdown has been completed. -
addAppVersion
Register the specified application version for future calls toserviceRequest.- Throws:
FileNotFoundException- If any of the specified files could not be located.
-
setSessionStoreFactory
Deprecated.Sets theSessionStoreFactorythat will be used to create the list ofSessionStores to which the HTTP Session will be stored, if sessions are enabled. This method must be invoked afterstart(java.lang.String, com.google.apphosting.runtime.ServletEngineAdapter.Config).
-